<?php

/**
* PHP versions 4 and 5
*
* LICENSE: This source file is subject to version 3.0 of the PHP license
* that is available through the world-wide-web at the following URI:
* http://www.php.net/license.  If you did not receive a copy of
* the PHP License and are unable to obtain it through the web, please
* send a note to license@php.net so we can mail you a copy immediately.
*
* @package    QuickTalk Guestbook
* @author     Philippe Vandenberghe <info@qt-cute.org>
* @copyright  2009-2012 The PHP Group
* @version    2.0 build:20091003
*/

session_start();
$pg_name='Statistics';

require_once('bin/qtg_init.php');
include(GetLang().'qtg_adm.php');
$qtg_skin = 'admin';

$intYear = intval(date('Y')); if ( intval(date('n'))<2 ) $intYear--; // year filter

$ch = array('time'=>'m','type'=>'b','value'=>'a','trend'=>'a'); // chart parameters
// blocktime: m=month, q=quarter, d=10days 
// graph type: b=bar, l=line, B=bar+variation, L=line+variation
// graphics reals: a=actual, p=percent
// trends reals: a=actual, p=percent

// --------
// SUBMITTED
// --------

if ( isset($_GET['y']) )
{
  $y = intval(strip_tags($_GET['y']));
  if ( !QTisbetween($y,2000,$intYear+1) ) die('Invalid target year');
  $intYear=$y;
}
if ( isset($_GET['ch']) )
{
  $str = strip_tags($_GET['ch']);
  if ( strlen($str)>0 ) $ch['time'] = substr($str,0,1); // blocktime
  if ( strlen($str)>1 ) $ch['type'] = substr($str,1,1); // graph type
  if ( strlen($str)>2 ) $ch['value'] = substr($str,2,1); // value type
  if ( strlen($str)>3 ) $ch['trend'] = substr($str,3,1); // trends value type
}

// --------
// STATS
// --------

$arrYears = array($intYear-1=>$intYear-1,$intYear=>$intYear);
include('qtg_adm_stat_inc.php');

// --------
// HTML START
// --------

echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" dir="',$L['Html_dir'],'" xml:lang="',$L['Html_lang'],'" lang="',$L['Html_lang'],'">
<head>
<title>',$qtg_title,'</title>
<meta http-equiv="content-type" content="text/html; charset=',$L['Html_charset'],'"/>
<link rel="stylesheet" type="text/css" href="admin/qtg_print.css"/>
<link rel="stylesheet" type="text/css" href="admin/qtg_graph.css"/>
</head>
<body>
';

// BANNER

if ($qtg_banner)
{
echo '
<!-- BANNER TOP -->
<div class="banner">
<table class="banner" cellspacing="0" cellpadding="0">
<tr class="banner">
<td class="banner_l"></td>
<td class="banner_c"><img id="logo" src="admin/qtg_logo.gif" width="175" height="50" alt="QuickTalk Guestbook"/></td>
<td class="banner_r"></td>
</tr>
</table>
</div>
';
}
else
{
echo '
<!-- NO BANNER TOP -->
<div class="nobanner">
<table class="nobanner" cellspacing="0" cellpadding="0">
<tr class="nobanner">
<td class="nobanner_l"></td>
<td class="nobanner_c"></td>
<td class="nobanner_r"></td>
</tr>
</table>
</div>
';
}

echo '
<h1>',$L['Statistics'],'</h1>
<h2>',$L['General_stats'],'</h2>
';

echo '
<table class="admin" cellspacing="0">
<tr>
<td class="admin_top" width="180">',$L['Messages'],'</td>
<td class="admin">',$intTotalPost,'</td>
</tr>
<tr>
<td class="admin_top">',$L['Hidden_messages'],'</td>
<td class="admin">',$intHiddenPost,'</td>
</tr>
<tr>
<td class="admin_top">',$L['First_message'],'</td>
<td class="admin">',$strFirstdate,'</td>
</tr>
<tr>
<td class="admin_top">',$L['Last_message'],'</td>
<td class="admin">',$strLastdate,'</td>
</tr>
</table>
';

// QUERY

$intTotalPost = 0;

echo '<h2>',$L['Messages_per_'.$ch['time']],'</h2>',N;

// Display table header

echo '<table class="admin" cellspacing="0">',N;
echo '<tr>',N;
echo '<td class="admin_top" style="width:50px">&nbsp;</td>',N;
switch($ch['time'])
{
case 'q': for ($i=1;$i<=$intMaxBt;$i++) { echo '<td class="admin_top" style="text-align:center;">Q',$i,'</td>'; } break;
case 'm': for ($i=1;$i<=$intMaxBt;$i++) { echo '<td class="admin_top" style="text-align:center;">',$L['dateMM'][$i],'</td>'; } break;
case 'd': for ($i=1;$i<=$intMaxBt;$i++) { echo '<td class="admin_top" style="text-align:center;">',str_replace(' ','<br/>',QTdatestr(DateAdd($strTendaysago,$i,'day'),'d M','')),'</td>'; } break;
}
echo '<td class="admin_top" style="text-align:center;"><b>',($ch['time']=='d' ? '10 '.strtolower($L['Days']) : $L['Total']),'</b></td>
</tr>';

// DISPLAY MESSAGES

foreach($arrYears as $y)
{
  echo '<tr>',N;
  echo '<td class="admin_top">',$y,'</td>',N;
  for ($intBt=1;$intBt<=$intMaxBt;$intBt++) 
  {
    echo '<td class="admin" style="text-align:center;">',(isset($arrT[$y][$intBt]) ? $arrT[$y][$intBt] : '&middot;'),'</td>',N;
  }
  echo '<td class="admin" style="text-align:center;padding:5px;"><b>',$arrTs[$y],'</b></td>',N;
  echo '</tr>';
}
echo '</table>',N;

// After values display, change the null values to zero to be able to make charts

foreach($arrYears as $y) $arrT[$y]=QTarrayzero($arrT[$y]);

// GRAPH

if ( file_exists('bin/qt_lib_graph.php') && file_exists('admin/qtg_graph.css') )
{
  $y = intval(date('Y')); // add current year if not in $arrYears
  if ( !in_array($y,$arrYears) ) $arrYears[$y]=$y;

  echo '<p>',$intYear,'</p>',N;
  QTbarchart(QTarraymerge($arrA,$arrT[$intYear]),320,100,QTroof($arrT[$intYear]),2,true,$L['Items_per_'.$ch['time']],'','1');
  QTbarchart(QTarraymerge($arrA,QTpercent($arrT[$intYear])),350,100,100,2,'P',$L['Items_per_'.$ch['time']].' (%)','','1');
  QTbarchart(QTarraymerge($arrA,QTcumul($arrT[$intYear])),320,100,QTroof($arrT[$intYear]),2,true,$L['Items_per_'.$ch['time'].'_cumul'],'','1');
}
else
{
  echo '<p class="small">Graphs cannot be displayed because one of these files is missing: bin/qt_lib_graph.php, ',$qtg_skin.'/qtg_graph.css</p>';
}

// IP STATS

$query = 'SELECT ip,count(ip) as countip FROM '.TABMESSAGE.' WHERE id>=0 GROUP BY ip ORDER BY countip DESC';
if ($oDB->type=='access') $query = 'SELECT DISTINCT ip,count(ip) as countip FROM '.TABMESSAGE.' WHERE id>=0 GROUP BY ip ORDER BY count(ip) DESC';
$oDB->Query($query);
$ips='';
$i=1;
while($row=$oDB->Getrow())
{
  $ip = $row['ip'];
  if ($ip=='') $ip='?.?.?.?';
  $ips .= "<b>{$row['countip']}</b> - $ip<br/>";
  $i++;
  if ($i>5) break;
}

echo '
<h2>',$L['Advenced_stats'],'</h2>
<table class="admin" cellspacing="0">
<tr>
<td class="admin_top" width="180" style="vertical-align:top">Top 5 IPs</td>
<td class="admin">',$ips,'</td>
</tr>
</table>
<br/>
';

// --------
// HTML END
// --------
echo '
<!-- COPYRIGHT LINE -->
<p class="copyright">powered by QT-cute | v',substr(QTGVERSION,0,3),'</p>
<!-- END COPYRIGHT LINE -->

</body>
</html>';

?>